summaryrefslogtreecommitdiffstats
path: root/cuda/2d/astra.h
diff options
context:
space:
mode:
Diffstat (limited to 'cuda/2d/astra.h')
-rw-r--r--cuda/2d/astra.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/cuda/2d/astra.h b/cuda/2d/astra.h
index d2d7059..efbac1d 100644
--- a/cuda/2d/astra.h
+++ b/cuda/2d/astra.h
@@ -78,9 +78,10 @@ public:
// fDetSize indicates the size of a detector pixel compared to a
// volume pixel edge.
//
// pfAngles will only be read from during this call.
bool setFanGeometry(unsigned int iProjAngles,
unsigned int iProjDets,
+ const astraCUDA::SFanProjection *fanProjs,
const float *pfAngles,
float fOriginSourceDistance,
float fOriginDetectorDistance,
@@ -78,9 +78,10 @@ public:
// volume pixel edge.
//
- // pfAngles will only be read from during this call.
+ // pfAngles, fanProjs will only be read from during this call.
bool setFanGeometry(unsigned int iProjAngles,
unsigned int iProjDets,